==> qtjambi-uic-6.4.2-sources.jar: io/qt/uic/ui4/DomPropertyToolTip.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomPropertyToolTip</p>
 */
public class DomPropertyToolTip extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomPropertyToolTip(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPropertyToolTip instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeName(){
        return attributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeName_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeName(){
        clearAttributeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeName_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeName(){
        return hasAttributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeName_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeName(java.lang.String a){
        setAttributeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeName_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomPropertyToolTip(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.1-sources.jar: io/qt/uic/ui4/DomPropertyToolTip.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomPropertyToolTip</p>
 */
public class DomPropertyToolTip extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomPropertyToolTip(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPropertyToolTip instance);
    
    @QtUninvokable
    public final java.lang.@NonNull String attributeName(){
        return attributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeName_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void clearAttributeName(){
        clearAttributeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeName_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasAttributeName(){
        return hasAttributeName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeName_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setAttributeName(java.lang.@NonNull String a){
        setAttributeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeName_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomPropertyToolTip(QPrivateConstructor p) { super(p); } 
    
}
